@@ -8,12 +8,18 @@ class reminder():
     def __init__(self, **kwargs):
         assert 'url' in kwargs.keys(), 'url should be given'
         assert 'email' in kwargs.keys(), 'email should be given'
+        assert 'mode' not in kwargs.keys(), 'mode should not be given'
+        assert 'csrfmiddlewaretoken' not in kwargs.keys(), 'csrfmiddlewaretoken should not be given'
+        assert 'error' not in kwargs.keys(), 'error should not be given'
         if 'url' in kwargs.keys():
             setattr(self,'url',kwargs['url'])
         self.data = dict()
         for k,v in kwargs.items():
             if k == 'url':
                 continue
+            elif k == "files":
+                self.files = v
+                continue
             self.data[k] = v
         self.data['mode'] = 'remind'
         
@@ -22,11 +28,17 @@ class reminder():
         def do(*args, **kwargs):
             self.data['filepath'] = os.getcwdb()
             try:
+                error = None
                 result = func(*args, **kwargs)
-                self.post()
-                return result
+            except Exception as e:
+                error = str(e.__class__) + str(e)
+                e_copy = e
             finally:
-                self.post(error=1)
+                self.post(error=error)
+                if error == None:
+                    return result
+                else:
+                    raise e_copy
         return do
 
     def post(self, error=None):
@@ -38,4 +50,9 @@ class reminder():
         self.data['csrfmiddlewaretoken'] = token
         if error != None:
             self.data['error'] = error
-        session.post(url=self.url, data=self.data, headers=session.headers, cookies=session.cookies)
+        files = dict()
+        if hasattr(self,"files"):
+            for file in self.files:
+                filename = file[file.rfind(os.sep)+1:]
+                files[filename] = open(file,'rb')
+        session.post(url=self.url, data=self.data, headers=session.headers, cookies=session.cookies,files=files)
